==> hazelcast-all-3.1.3-sources.jar: com/hazelcast/concurrent/semaphore/client/ReduceRequest.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.concurrent.semaphore.client;

import com.hazelcast.concurrent.semaphore.ReduceOperation;
import com.hazelcast.concurrent.semaphore.SemaphorePortableHook;
import com.hazelcast.security.permission.ActionConstants;
import com.hazelcast.security.permission.SemaphorePermission;
import com.hazelcast.spi.Operation;

import java.security.Permission;

/**
 * @author ali 5/13/13
 */
public class ReduceRequest extends SemaphoreRequest {

    public ReduceRequest() {
    }

    public ReduceRequest(String name, int permitCount) {
        super(name, permitCount);
    }

    protected Operation prepareOperation() {
        return new ReduceOperation(name, permitCount);
    }

    public int getClassId() {
        return SemaphorePortableHook.REDUCE;
    }

    public Permission getRequiredPermission() {
        return new SemaphorePermission(name, ActionConstants.ACTION_ACQUIRE);
    }
}

==> hazelcast-all-3.5.2-sources.jar: com/hazelcast/concurrent/semaphore/client/ReduceRequest.java <==
/*
 * Copyright (c) 2008-2015, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.concurrent.semaphore.client;

import com.hazelcast.concurrent.semaphore.operations.ReduceOperation;
import com.hazelcast.security.permission.ActionConstants;
import com.hazelcast.security.permission.SemaphorePermission;
import com.hazelcast.spi.Operation;

import java.security.Permission;

public class ReduceRequest extends SemaphoreRequest {

    public ReduceRequest() {
    }

    public ReduceRequest(String name, int permitCount) {
        super(name, permitCount);
    }

    @Override
    protected Operation prepareOperation() {
        return new ReduceOperation(name, permitCount);
    }

    @Override
    public int getClassId() {
        return SemaphorePortableHook.REDUCE;
    }

    @Override
    public Permission getRequiredPermission() {
        return new SemaphorePermission(name, ActionConstants.ACTION_ACQUIRE);
    }

    @Override
    public String getMethodName() {
        return "reducePermits";
    }
}
